@@ -104,53 +104,3 @@ def makejs(
         output = javascript
     
     return output
-
-def main():
-    """
-    Print a JavaScript implementation of CiteURL's lookup function,
-    populated with the templates from the specified YAML files, plus the
-    built-in templates by default.
-    
-    The JavaScript is meant to be embedded in a HTML page that contains
-    a search bar with name="q", inside of a form with
-    onsubmit="handleSearch(event)".
-    """
-    parser = ArgumentParser(description=main.__doc__)
-    parser.add_argument(
-        "yaml_files",
-        nargs="*",
-        help="files containing custom citation templates to include. "
-            + "See https://raindrum.github.io/citeurl/#template-yamls/",
-    )
-    parser.add_argument(
-        "-n", "--no-default-templates",
-        action="store_true",
-        help="don't include CiteURL's default templates",
-    )
-    parser.add_argument(
-        "-e", "--embed-html",
-        action="store_true",
-        help="generate an embeddable HTML form instead of just JavaScript",
-    )
-    parser.add_argument(
-        "-o", "--output",
-        metavar="FILE",
-        help="write output to a file instead of stdout",
-    )
-    args = parser.parse_args()
-    
-    citator = Citator(
-        yaml_paths=args.yaml_files,
-        defaults=False if args.no_default_templates else True,
-    )
-    
-    output = makejs(
-        citator,
-        embed_html=args.embed_html,
-    )
-
-    # save or print output
-    if args.output:
-        Path(args.output).write_text(output)
-    else:
-        print(output)
